<?php

/**
 * Build a drupal dir and use it as source to
 * make package from.
 */
function dh_set_root($vc_engine, $tag = NULL) {
  if (!drush_get_option('dh-build-dir') && $vc_engine) {
    $build_dir = realpath('/tmp') . '/' . drush_get_option('dh-package');
    $build_dir = drush_prompt(dt("Where would you like !version_control to checkout '!build' to build package from?", array(
      '!version_control' => $vc_engine->name(),
      '!build' => drush_get_option('dh-version'))),
    $build_dir);
    drush_set_option('dh-build-dir', $build_dir);
  }
  if (drush_get_option('dh-build-dir') && $vc_engine) {
    $branch = $tag ? $tag : $vc_engine->getBranch();
    return $vc_engine->export($branch, drush_get_option('dh-build-dir')) ? drush_get_option('dh-build-dir') : DRUPAL_ROOT;
  }
  drush_set_option('dh-build-dir', DRUPAL_ROOT);
  return DRUPAL_ROOT;
}

/**
 * Copy a template directory into the drupal project and build the package.
 */
function dh_create_debian() {
  $dh_tpl_dir = dirname(__FILE__) . '/share';

  $dir = drush_get_option('dh-build-dir') . '/debian';

  // Make the debian folder.
  if (!is_dir($dir) && !mkdir($dir, 0755)) {
    return drush_set_error(dt("Cannot create directory !dir", array('!dir' => $dir)));
  }

  // Copy everything over by default.
  $pwd = exec("pwd");
  chdir($dh_tpl_dir . '/debian');
  drush_shell_exec('tar --exclude="*.swp" -c * | tar -x -C %s', $dir);
  chdir($pwd);

  drush_shell_exec('find %s', $dh_tpl_dir . '/debian');
  $vhost_files = array();

  $output = drush_shell_exec_output();
  rsort($output);

  foreach ($output as $file) {
    if (!is_file($file)) {
      continue;
    }
    $relpath  = str_replace($dh_tpl_dir . '/debian', $dir, $file);
    if (strpos($file, 'apache') !== FALSE || strpos($file, 'nginx') !== FALSE) {
      $vhost_files[] = $relpath;
    }
    if ($contents = dh_debian_file($file)) {
      file_put_contents($relpath, $contents);
    }
  }
  // Offer a hook to add addtional information into vhost files.
  // This will be appended to the bottom of the vhost file.
  if (!empty($vhost_files)) {
    $apache_conf = module_invoke_all('dh_vhost_apache');
    $nginx_conf  = module_invoke_all('dh_vhost_nginx');
    foreach ($vhost_files as $file) {
      if (strpos($file, 'nginx') !== FALSE) {
        file_put_contents($file, PHP_EOL . implode(PHP_EOL, $nginx_conf), FILE_APPEND);
      }
      else {
        file_put_contents($file, PHP_EOL . implode(PHP_EOL, $apache_conf), FILE_APPEND);
      }
    }
  }

  // Allow modules to place files into debian folder.
  $files = module_invoke_all('debian_create');
  foreach ($files as $file => $location) {
    // Don't replace an existing file as it maybe an override.
    if (!file_exists($dir . '/' . $location)) {
      if (!@copy($file, $dir . '/' . $location)) {
        drush_set_error("Failed to copy $file to $dir/$location");
      }
    }
  }

  // Allow project overrides.
  chdir(DRUPAL_ROOT . '/.debian');
  drush_shell_exec('tar --exclude="*.swp" -c * | tar -x -C %s', $dir);
  chdir($pwd);

  // Variable replacement.
  dh_replace($dir, array(
    '__USER__' => drush_get_option('dh-user'),
    '__EMAIL__' => drush_get_option('dh-email'),
    '__VERSION__' => drush_get_option('dh-version'),
    '__PACKAGE__' => drush_get_option('dh-package'),
    '__PROJECT__' => drush_get_option('dh-project'),
    '__WWWROOT__' => drush_get_option('wwwroot'),
    '__WWWROOTNS__' => drush_get_option('wwwrootns'),
    '__CRONFREQ__' => (int) drush_get_option('dh-cron-frequency', 12),
  ));

  return TRUE;
}

/**
 * Recursively read the contents of a dir and replace variables in contents and filenames.
 */
function dh_replace($dir, $variables) {
  if (!$dh = opendir($dir)) {
    drush_set_error("Failed to open $dir");
    return FALSE;
  }
  while (false !== ($file = readdir($dh))) {
    if (in_array($file, array('.', '..'))) continue;
    $filename = realpath("$dir/$file");
    if (is_dir($filename)) {
      if (!dh_replace($filename, $variables)) {
        return FALSE;
      }
    }
    else {
      // Rename files with variable replacements also.
      $contents = strtr(file_get_contents($filename), $variables);
      unlink($filename);
      file_put_contents(strtr($filename, $variables), $contents);
    }
  }
  return TRUE;
}

/**
 * Suggest to the user some drushrc configuration options.
 */
function dh_recommend_drushrc() {
  // Bring RC configuration into scope.
  $options = array();
  if ($rc = _drush_config_file('drupal')) {
    if (file_exists($rc)) {
      include $rc;
    }
  }
  if ($rc = _drush_config_file('site')) {
    if (file_exists(DRUPAL_ROOT . '/' . $rc)) {
      include DRUPAL_ROOT . '/' . $rc;
    }
  }
  $config = array(
    'dh-project',
    'dh-bump-version',
    'dh-build-dir',
  );
  if (!drush_get_option('version-control')) {
    $config[] = 'dh-user';
    $config[] = 'dh-email';
  }
  $suggestions = array_diff($config, array_keys($options));
  if (empty($suggestions)) {
    return;
  }
  drush_print("");
  drush_print("It is recommended to add the following settings to a local drushrc file:", 2);
  foreach ($suggestions as $key) {
    $value = drush_get_option($key);
    if (is_null($value)) $value = FALSE;
    drush_print('$options["' . $key . '"] = ' . var_export($value, TRUE) . ';', 4);
  }

  if (!drush_get_option('dh-build-ssl', FALSE)) {
    drush_print("");
    drush_print("To automatically enable SSL support, generate an RSA cert and key and store in .debian/cert.pem");
  }
}
