server {
<?php if (!$ssl_support || !($ssl_mode == 'ssl_only' || $ssl_mode == 'redirect_to_ssl')): ?>
  listen <?php print ($ipv6 ? '[::]' : '*'); ?>:<?php print $port; ?>;
<?php endif; ?><?php if ($ssl_support): ?>
  # default required before nginx 0.8
  listen <?php print ($ipv6 ? '[' . $ssl_ip . ']' : $ssl_ip); ?>:<?php print $ssl_port; ?> default ssl;

  ssl_protocols SSLv3 TLSv1;
  ssl_ciphers ALL:!ADH:RC4+RSA:+HIGH:+MEDIUM:!LOW:!SSLv2:!EXP;
  ssl_certificate <?php print $ssl_cert; ?>;
  ssl_certificate_key <?php print $ssl_cert; ?>;
<?php endif; ?>

  server_name <?php print $servername; if (!empty($serveralias)) { print " $serveralias"; } ?>;

  root <?php print WEBROOT; ?>;
  access_log /var/log/sitelogs/<?php print PACKAGE_NAME; ?>/access-nginx.log combined;
  error_log /var/log/sitelogs/<?php print PACKAGE_NAME; ?>/error-nginx.log;

  gzip off; # turn on again in certain circumstances
  charset utf-8;

  # Allows nginx to fall back through a chain of errors to our 500 handler
  recursive_error_pages on;

  # Buffers definition. allows of up to 260k to be passed in memory.
  client_max_body_size 512m;
  proxy_buffering on;
  proxy_buffer_size 4k;
  proxy_buffers 8 32k;

  # error_page 404 defaults to /index.php
<?php print $error_page_404 . PHP_EOL; ?>

  # This is mostly based on Drupal's stock .htaccess
  location ~* ^.+(\.(txt|scripts|engine|inc|info|install|module|profile|po|sh|.*sql|theme|tpl(\.php)?|xtmpl)|code-style\.pl)$ {
    return 403;
  }

  location ~ ^.+(/Entries.*|/Repository|/Root|/Tag|/Template)$ {
    return 403;
  }

  # serve imagecache files directly or redirect to drupal if they do not exist
  location ~* imagecache {
    expires 2w;
    try_files $uri @drupal;
  }

  # serve D7 imagecache files directly or redirect to drupal if they do not exist
  location ~* files/styles/ {
    expires 2w;
    try_files $uri @drupal;
  }
 
  # Drupal 7 image style
  location ~* image/generate {
    expires 2w;
    try_files $uri @drupal;
  }

  # Needed for private file system
  location ~* system/files {
    expires 2w;
    try_files $uri @drupal;
  }

  # static files can have a long expiry on them
  location ~* ^.+\.(jpg|jpeg|gif|png|ico|html|swf|flv)$ {
    expires 2w;
  }

  # Try boost before local for JS and CSS
  location ~* ^.+\.js$ {
    error_page 406 = @boost_js_gzip;
    if ($http_accept_encoding ~* "gzip") {
      return 406;
    }
  }
  location ~* ^.+\.css$ {
    error_page 406 = @boost_css_gzip;
    if ($http_accept_encoding ~* "gzip") {
      return 406;
    }
  }

  # Send php requests to Apache
  location ~* ^.+\.php$ {
    try_files @drupal @drupal;
  }

  # This sends pages to PHP for processing
  # Called on imagecache and boost failure
  location @drupal {
    # Fall through to Apache (which will do the rewrite)
    gzip on;
    gzip_disable "MSIE [1-6]\.";
    proxy_set_header Host $host;
    proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
    proxy_set_header X-Forwarded-By "nginx";
    proxy_pass http://localhost:<?php print $apache_port; ?>;
    proxy_redirect off;
    proxy_read_timeout 600;
    proxy_connect_timeout 600;
    # set this to 'on' to allow nginx to serve error pages
    proxy_intercept_errors <?php print $proxy_intercept_errors; ?>; # default: off
    add_header X-Boost "MISS";
  }

  location /ssi.php {
    try_files @drupal @drupal;
  }

  # The main match that'll serve images etc directly and let the rest fall through to Drupal via a boost check
  location / {
<?php print $htpasswd; ?>
    try_files $uri @html_cache;
  }

  # START BOOST RULES

  # This will try to see if we have a boost file in place. no harm done if this is not used
  location @html_cache {
    # queries, drupal cookies, or not GET methods, all require PHP processing.
    if ($query_string ~ ".+") {
      return 405;
    }
    if ($http_cookie ~ "(DRUPAL_UID|NO_CACHE|SsoSession_Cookie)" ) {
      return 405;
    }
    if ($request_method !~ ^(GET|HEAD)$) {
      return 405;
    }
    if ($http_cache_control ~ "no-cache") {
      return 405;
    }
    error_page 405 = @drupal;

    # Drupal uses 1978 - I am 4 years older than Dries :)
    add_header Expires "Tue, 22 Sep 1974 08:00:00 GMT";
    add_header Cache-Control "must-revalidate, post-check=0, pre-check=0";

    if ($http_cookie ~ "boost-gzip") {
      return 406;
    }
    if ($http_accept_encoding ~* "gzip") {
      return 406;
    }
    error_page 406 = @html_cache_gzip;

    add_header Expires "Tue, 24 Jan 1984 08:00:00 GMT";
    add_header Cache-Control "must-revalidate, post-check=0, pre-check=0";
    add_header Vary "Cookie";
    add_header X-Boost "HIT";
    default_type text/html;
    try_files /cache/normal/$host/${uri}_${args}_.html /cache/normal/$host/${uri}_${args}.html /cache/$host/0$uri.html /cache/$host/0${uri}/index.html @drupal;
  }

  # For HTML pages served to browsers that handle GZIP
  location @html_cache_gzip {
    add_header Expires "Tue, 24 Jan 1984 08:00:00 GMT";
    add_header Content-encoding "gzip";
    add_header Vary "Accept-encoding,Cookie";
    add_header X-Boost "HIT-GZIP";
    default_type text/html;
    try_files /cache/normal/$host/${uri}_${args}_.html.gz /cache/normal/$host/${uri}_${args}.html.gz /cache/$host/0$uri.html.gz /cache/$host/0${uri}/index.html.gz @drupal;
  }

  location @boost_js_gzip {
    expires 2w;
    add_header Content-encoding "gzip";
    add_header Vary "Accept-encoding,Cookie";
    add_header X-Boost "HIT-GZIP";
    default_type text/javascript;
    try_files /cache/perm/$host/${uri}_.js.gz @static;
  }

  location @boost_css_gzip {
    expires 2w;
    add_header Content-encoding "gzip";
    add_header Vary "Accept-encoding,Cookie";
    add_header X-Boost "HIT-GZIP";
    default_type text/css;
    try_files /cache/perm/$host/${uri}_.css.gz @static;
  }

  location @static {
    expires 2w;
    add_header X-Boost "HIT-STATIC";
  }

  # END BOOST RULES

<?php print $custom . PHP_EOL; ?>
}
<?php if (!empty($serverredirects)): ?>
server {
<?php if (!$ssl_support || !($ssl_mode == 'ssl_only')): ?>
  listen <?php print ($ipv6 ? '[::]' : '*'); ?>:<?php print $port; ?>;
<?php endif; ?><?php if ($ssl_support): ?>
  listen <?php print ($ipv6 ? '[' . $ssl_ip . ']' : $ssl_ip); ?>:<?php print $ssl_port; ?>;
<?php endif; ?>

  server_name <?php foreach ($serverredirects as $redirect) { print $redirect . ' '; } ?>;
  root <?php print WEBROOT; ?>;
  error_log /var/log/sitelogs/<?php print PACKAGE_NAME; ?>/error-nginx.log;

<?php print $redirect_custom . PHP_EOL; ?>
  location / {
    rewrite ^ <?php print (($ssl_mode == 'redirect_to_ssl') ? 'https' : '$scheme'); ?>://<?php print $servername; ?>$request_uri? permanent;
  }
}
<?php endif; ?>
<?php if ($ssl_mode == 'redirect_to_ssl'): ?>
server {
  listen <?php print ($ipv6 ? '[::]' : '*'); ?>:<?php print $port; ?>;

  server_name <?php print $servername . ' '; ?>;
  root <?php print WEBROOT; ?>;
  error_log /var/log/sitelogs/<?php print PACKAGE_NAME; ?>/error-nginx.log;

<?php print $redirect_to_ssl_custom . PHP_EOL; ?>
  location / {
    rewrite ^ https://<?php print $servername; ?>$request_uri? permanent;
  }
}
<?php endif; ?>
