server {
<?php if (!$ssl_support || !($ssl_mode == 'ssl_only' || $ssl_mode == 'redirect_to_ssl')): ?>
  listen <?php print ($ipv6 ? '[::]' : '*'); ?>:<?php print $port; ?>;
<?php endif; ?><?php if ($ssl_support): ?>
  # default required before nginx 0.8
  listen <?php print ($ipv6 ? '[' . $ssl_ip . ']' : $ssl_ip); ?>:<?php print $ssl_port; ?> default ssl;

  ssl_protocols SSLv3 TLSv1;
  ssl_ciphers ALL:!ADH:RC4+RSA:+HIGH:+MEDIUM:!LOW:!SSLv2:!EXP;
  ssl_certificate <?php print $ssl_cert; ?>;
  ssl_certificate_key <?php print $ssl_cert; ?>;
<?php endif; ?>

  server_name <?php print $servername; if (!empty($serveralias)) { print " $serveralias"; } ?>;

  root <?php print WEBROOT; ?>;
  access_log /var/log/sitelogs/<?php print PACKAGE_NAME; ?>/access-nginx.log combined;
  error_log /var/log/sitelogs/<?php print PACKAGE_NAME; ?>/error-nginx.log;

  gzip off; # turn on again in certain circumstances
  charset utf-8;

  # Allows nginx to fall back through a chain of errors to our 500 handler
  recursive_error_pages on;

  # error_page 404 and 403 default to /index.php
<?php print $error_page_404 . PHP_EOL; ?>
<?php print $error_page_403 . PHP_EOL; ?>

  # This is mostly based on Drupal's stock .htaccess
  location ~* ^.+(\.(txt|scripts|engine|inc|info|install|module|profile|po|sh|.*sql|theme|tpl(\.php)?|xtmpl)|code-style\.pl)$ {
    return 403;
  }

  location ~ ^.+(/Entries.*|/Repository|/Root|/Tag|/Template)$ {
    return 403;
  }

  # serve imagecache files directly or redirect to drupal if they do not exist
  location ~* imagecache {
    expires 2w;
    try_files $uri @drupal;
  }

  # serve D7 imagecache files directly or redirect to drupal if they do not exist
  location ~* files/styles/ {
    expires 2w;
    try_files $uri @drupal;
  }

  # Drupal 7 image style
  location ~* image/generate {
    expires 2w;
    try_files $uri @drupal;
  }

  # Needed for private file system
  location ~* system/files {
    expires 2w;
    try_files $uri @drupal;
  }

  # static files can have a long expiry on them
  location ~* ^.+\.(jpg|jpeg|gif|png|ico|html|swf|flv)$ {
    expires 2w;
  }

  # Try boost before local for JS and CSS
  location ~* ^.+\.js$ {
    error_page 406 = @boost_js_gzip;
    if ($http_accept_encoding ~* "gzip") {
      return 406;
    }
    try_files @static @static;
  }

  location ~* ^.+\.css$ {
    error_page 406 = @boost_css_gzip;
    if ($http_accept_encoding ~* "gzip") {
      return 406;
    }
    try_files @static @static;
  }

  location / {
<?php print $htpasswd; ?>
    # Server the actual file or from the cache.
    try_files $uri @html_cache;
  }

  location @drupal {
    # now simplified to reduce rewrites
    rewrite ^/(.*)$ /index.php?q=$1 last;
  }

  location ~ \.php$ {
    include /etc/nginx/fastcgi_params;
    try_files $uri @drupal; #check for existence of php file
    fastcgi_pass  unix:<?php print $socket; ?>;
    fastcgi_index index.php;
    fastcgi_param SCRIPT_FILENAME  $document_root$fastcgi_script_name;
    # set this to 'on' to allow nginx to serve error pages
    fastcgi_intercept_errors <?php print $fastcgi_intercept_errors; ?>; # default: off
    fastcgi_read_timeout <?php print $fastcgi_read_timeout; ?>; # default: 120;
    fastcgi_send_timeout <?php print $fastcgi_send_timeout; ?>; # default: 120;
    # Detect whether we are using SSL, and set $_SERVER['HTTPS'] accordingly
    if ($server_port = 443) {
      set $php_ssl on;
    }
    fastcgi_param HTTPS $php_ssl;
  }

  # START BOOST RULES

  location @html_cache {
    # Set drupal as the error page for 405 so that if anything returns a 405
    # it will get sent to Drupal. This is a roundabout way of preventing Nginx
    # from checking the Boost cache.
    error_page 405 = @drupal;
    if ($request_method !~ ^(GET|HEAD)$) {
      return 405;
    }
    if ($http_cookie ~ "(DRUPAL_UID|NO_CACHE)") {
      return 405;
    }
    if ($http_cache_control ~ "no-cache") {
      return 405;
    }

    # Likewise, if the browser supports gzip, return a 406 error
    # which will be handled by the gzip_cache handler.
    error_page 406 = @html_cache_gzip;
    if ($http_accept_encoding ~* "gzip") {
      return 406;
    }

    add_header Expires "Tue, 24 Jan 1984 08:00:00 GMT";
    add_header Cache-Control "must-revalidate, post-check=0, pre-check=0";
    add_header Vary "Cookie";
    add_header X-Boost "HIT";
    default_type text/html;
    try_files /cache/normal/$host/${uri}_${args}_.html /cache/normal/$host/${uri}_${args}.html /cache/$host/0$uri.html /cache/$host/0${uri}/index.html @drupal;
  }

  # For HTML pages served to browsers that handle GZIP
  location @html_cache_gzip {
    add_header Expires "Tue, 24 Jan 1984 08:00:00 GMT";
    add_header Content-encoding "gzip";
    add_header Vary "Accept-encoding,Cookie";
    add_header X-Boost "HIT-GZIP";
    default_type text/html;
    try_files /cache/normal/$host/${uri}_${args}_.html.gz /cache/normal/$host/${uri}_${args}.html.gz /cache/$host/0$uri.html.gz /cache/$host/0${uri}/index.html.gz @drupal;
  }

  location @boost_js_gzip {
    expires 2w;
    add_header Content-encoding "gzip";
    add_header Vary "Accept-encoding,Cookie";
    add_header X-Boost "HIT-GZIP";
    default_type text/javascript;
    try_files /cache/perm/$host/${uri}_.js.gz @static;
  }

  location @boost_css_gzip {
    expires 2w;
    add_header Content-encoding "gzip";
    add_header Vary "Accept-encoding,Cookie";
    add_header X-Boost "HIT-GZIP";
    default_type text/css;
    try_files /cache/perm/$host/${uri}_.css.gz @static;
  }

  location @static {
    expires 2w;
    add_header X-Boost "HIT-STATIC";
  }

  # END BOOST RULES

<?php print $custom . PHP_EOL; ?>
}
<?php if (!empty($serverredirects)): ?>
server {
<?php if (!$ssl_support || !($ssl_mode == 'ssl_only')): ?>
  listen <?php print ($ipv6 ? '[::]' : '*'); ?>:<?php print $port; ?>;
<?php endif; ?><?php if ($ssl_support): ?>
  listen <?php print ($ipv6 ? '[' . $ssl_ip . ']' : $ssl_ip); ?>:<?php print $ssl_port; ?>;
<?php endif; ?>

  server_name <?php foreach ($serverredirects as $redirect) { print $redirect . ' '; } ?>;
  root <?php print WEBROOT; ?>;
  error_log /var/log/sitelogs/<?php print PACKAGE_NAME; ?>/error-nginx.log;

<?php print $redirect_custom . PHP_EOL; ?>
  location / {
    rewrite ^ <?php print (($ssl_mode == 'redirect_to_ssl') ? 'https' : '$scheme'); ?>://<?php print $servername; ?>$request_uri? permanent;
  }
}
<?php endif; ?>
<?php if ($ssl_mode == 'redirect_to_ssl'): ?>
server {
  listen <?php print ($ipv6 ? '[::]' : '*'); ?>:<?php print $port; ?>;

  server_name <?php print $servername . ' '; ?>;
  root <?php print WEBROOT; ?>;
  error_log /var/log/sitelogs/<?php print PACKAGE_NAME; ?>/error-nginx.log;

<?php print $redirect_to_ssl_custom . PHP_EOL; ?>
  location / {
    rewrite ^ https://<?php print $servername; ?>$request_uri? permanent;
  }
}
<?php endif; ?>
